package com.ruoyi.mall.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallHotWordMapper;
import com.ruoyi.mall.domain.MallHotWord;
import com.ruoyi.mall.service.IMallHotWordService;

/**
 * 热词Service业务层处理
 * 
 * @author chang
 * @date 2021-11-25
 */
@Service
public class MallHotWordServiceImpl implements IMallHotWordService 
{
    @Autowired
    private MallHotWordMapper mallHotWordMapper;

    /**
     * 查询热词
     * 
     * @param id 热词主键
     * @return 热词
     */
    @Override
    public MallHotWord selectMallHotWordById(Long id)
    {
        return mallHotWordMapper.selectMallHotWordById(id);
    }

    /**
     * 查询热词列表
     * 
     * @param mallHotWord 热词
     * @return 热词
     */
    @Override
    public List<MallHotWord> selectMallHotWordList(MallHotWord mallHotWord)
    {
        return mallHotWordMapper.selectMallHotWordList(mallHotWord);
    }

    /**
     * 新增热词
     * 
     * @param mallHotWord 热词
     * @return 结果
     */
    @Override
    public int insertMallHotWord(MallHotWord mallHotWord)
    {
        return mallHotWordMapper.insertMallHotWord(mallHotWord);
    }

    /**
     * 修改热词
     * 
     * @param mallHotWord 热词
     * @return 结果
     */
    @Override
    public int updateMallHotWord(MallHotWord mallHotWord)
    {
        return mallHotWordMapper.updateMallHotWord(mallHotWord);
    }

    /**
     * 批量删除热词
     * 
     * @param ids 需要删除的热词主键
     * @return 结果
     */
    @Override
    public int deleteMallHotWordByIds(Long[] ids)
    {
        return mallHotWordMapper.deleteMallHotWordByIds(ids);
    }

    /**
     * 删除热词信息
     * 
     * @param id 热词主键
     * @return 结果
     */
    @Override
    public int deleteMallHotWordById(Long id)
    {
        return mallHotWordMapper.deleteMallHotWordById(id);
    }
}
