package com.ruoyi.mall.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallHotWord;
import com.ruoyi.mall.service.IMallHotWordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 热词Controller
 * 
 * @author chang
 * @date 2021-11-25
 */
@RestController
@RequestMapping("/mall/mallHotWord")
public class MallHotWordController extends BaseController
{
    @Autowired
    private IMallHotWordService mallHotWordService;

    /**
     * 查询热词列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallHotWord:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallHotWord mallHotWord)
    {
        startPage();
        List<MallHotWord> list = mallHotWordService.selectMallHotWordList(mallHotWord);
        return getDataTable(list);
    }

    /**
     * 导出热词列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallHotWord:export')")
    @Log(title = "热词", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallHotWord mallHotWord)
    {
        List<MallHotWord> list = mallHotWordService.selectMallHotWordList(mallHotWord);
        ExcelUtil<MallHotWord> util = new ExcelUtil<MallHotWord>(MallHotWord.class);
        return util.exportExcel(list, "热词数据");
    }

    /**
     * 获取热词详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallHotWord:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallHotWordService.selectMallHotWordById(id));
    }

    /**
     * 新增热词
     */
    @PreAuthorize("@ss.hasPermi('mall:mallHotWord:add')")
    @Log(title = "热词", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallHotWord mallHotWord)
    {
        return toAjax(mallHotWordService.insertMallHotWord(mallHotWord));
    }

    /**
     * 修改热词
     */
    @PreAuthorize("@ss.hasPermi('mall:mallHotWord:edit')")
    @Log(title = "热词", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallHotWord mallHotWord)
    {
        return toAjax(mallHotWordService.updateMallHotWord(mallHotWord));
    }

    /**
     * 删除热词
     */
    @PreAuthorize("@ss.hasPermi('mall:mallHotWord:remove')")
    @Log(title = "热词", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallHotWordService.deleteMallHotWordByIds(ids));
    }
}
